<?xml version="1.0" encoding="UTF-8"?>
<!-- fz813_814v2.0_Vecozo_stap1_v1, 18 april 2024 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:cod="http://ei.vektis.nl/codelijsten/v1"
xmlns:gen="http://ei.vektis.nl/generiekefuncties"
xmlns:fz813="http://ei.vektis.nl/verantwoording/fz813"
xmlns:fz814="http://ei.vektis.nl/verantwoording/fz814">

	<!-- VALXSLT 2 TRAPS RETOURBERICHT  - versie Vecozo -->
	<!-- Deze xslt doet stap 1, i.e. tussenresultaat retourbericht met alle klassen, identificerende gegevens van klassen en geconstateerde fouten -->
	
	<!-- Laden Configuratiefile met waarde voor Omgeving en Huidige datum -->
	<xsl:import href="config_Vecozo.xml"/>
	<xsl:import href="rcCheckWaarde_v1.0.xslt"/>
	<xsl:import href="rcCheckWaarde_ConditioneleWaarde_v1.0.xslt"/>
	<xsl:import href="rcCheckWaarde_vs_Key_v1.0.xslt"/>
	<xsl:import href="rcDatum_vs_SpecifiekeDatum_v1.0.xslt"/>
	<xsl:import href="rcDatum_vs_Peildatum_v1.0.xslt"/>
	<xsl:import href="rcTotaalbedragDC_vs_Details_v1.0.xslt"/>
	<xsl:import href="rcCode_vs_Peildatum_v1.0.xslt"/>
	
	<!-- Uitvoer is fz814_585 bericht met Retourcodes. -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
	
	<xsl:variable name="TargetNameSpace" select="'fz814:'"/>
	<!-- Onderstaande variabelen komen één keer voor in het bericht. -->
	<xsl:variable name="Berichtsoort" select="//fz813:Bericht/fz813:Header/fz813:Berichtsoort"/> 
	<xsl:variable name="VerzenderRol" select="//fz813:Bericht/fz813:Header/fz813:VerzenderRol"/>
	<xsl:variable name="Berichtcode" select="//fz813:Bericht/fz813:Header/fz813:Berichtcode"/> 
	<xsl:variable name="OntvangerRol" select="//fz813:Bericht/fz813:Header/fz813:OntvangerRol"/> 
	<xsl:variable name="Verzenddatum" select="//fz813:Bericht/fz813:Header/fz813:Verzenddatum"/>
	<xsl:variable name="ZorgaanbiederSoort" select="//fz813:Bericht/fz813:VerantwoordingsContext/fz813:Declarant/fz813:ZorgaanbiederSoort"/>
	<xsl:variable name="EinddatumVerantwoordingsperiode" select="//fz813:VerantwoordingsContext/fz813:EinddatumVerantwoordingsperiode"/>
	
	<!-- Key DebetReferentienummer om te bepalen of een credit samen met de gerelateerde debet in hetzelfde bericht zit -->
		<xsl:key name="DebetReferentienummer" match="//fz813:Bericht/fz813:Verzekerde/fz813:Prestatie/fz813:DebetPrestatie" use="fz813:Referentienummer"/>
		
	<!-- Controleer op fouten in de klasse Header -->
	<!-- RC003: VerzenderRol moet voorkomen in ketenpartij codelijst. | Indien VerzenderRol in ketenpartij voorkomt, dan moet de waarde van Verzenddatum groter zijn dan of gelijk zijn aan de waarde van ingangsdatum ketenpartij van VerzenderRol. | Indien expiratiedatum ketenpartij gevuld is, dan moet de waarde van Verzenddatum kleiner zijn dan de waarde van expiratiedatum ketenpartij van VerzenderRol. -->
	<xsl:variable name="rc003">
		<xsl:call-template name="rcCode_vs_Peildatum">
			<xsl:with-param name="Codelijst" select="'codelijsten/CL0002-VEKT.xml'"/>
			<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9302'"/>
			<xsl:with-param name="RetourcodeIngangsdatum" select="'9303'"/>
			<xsl:with-param name="RetourcodeExpiratiedatum" select="'9304'"/>
			<xsl:with-param name="Code" select="$VerzenderRol"/>
			<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- RC006: OntvangerRol moet voorkomen in ketenpartij codelijst. | Indien OntvangerRol in ketenpartij voorkomt, dan moet de waarde van Verzenddatum groter zijn dan of gelijk zijn aan de waarde van ingangsdatum ketenpartij van OntvangerRol. | Indien expiratiedatum ketenpartij gevuld is, dan moet de waarde van Verzenddatum kleiner zijn dan de waarde van expiratiedatum ketenpartij van OntvangerRol. -->
	<xsl:variable name="rc006">
		<xsl:call-template name="rcCode_vs_Peildatum">
			<xsl:with-param name="Codelijst" select="'codelijsten/CL0002-VEKT.xml'"/>
			<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9311'"/>
			<xsl:with-param name="RetourcodeIngangsdatum" select="'9312'"/>
			<xsl:with-param name="RetourcodeExpiratiedatum" select="'9313'"/>
			<xsl:with-param name="Code" select="$OntvangerRol"/>
			<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC001: De waarde van Berichtsoort moet voldoen aan de omgeving van VECOZO (productie of test) -->
	<xsl:variable name="vc001">
		<xsl:call-template name="rcCheckWaarde">
			<xsl:with-param name="TeControlerenElement" select="$Berichtsoort"/>
			<xsl:with-param name="VereisteWaarde" select="$OmgevingVecozo"/>
			<xsl:with-param name="Retourcode" select="'8028'"/>
		</xsl:call-template>
	</xsl:variable>
		<!-- VC002: Indien Berichtcode = 584 (= Verantwoording forensische zorg voor ZPM), dan mag alleen VerzenderRol = 1 (= Zorgaanbieder) of 2 (= Servicebureau) voorkomen. -->
	<xsl:variable name="vc002">
	<xsl:call-template name="rcCheckWaarde_ConditioneleWaarde">
		<xsl:with-param name="TeControlerenElement" select="$VerzenderRol"/>
		<xsl:with-param name="VereisteWaarde" select="'1|2'"/>
		<xsl:with-param name="ConditioneelElement" select="$Berichtcode"/>
		<xsl:with-param name="ConditioneleWaarde" select="'584'"/>
		<xsl:with-param name="Retourcode" select="'9262'"/>
	</xsl:call-template>
</xsl:variable>
<!-- VC004:Indien Berichtcode = 584 (= Verantwoording forensische zorg voor ZPM),dan mag alleen OntvangerRol = 2 (= Servicebureau) of 4 (= DJI) voorkomen.  -->
		<xsl:variable name="vc004">
		<xsl:call-template name="rcCheckWaarde_ConditioneleWaarde">
			<xsl:with-param name="TeControlerenElement" select="$OntvangerRol"/>
			<xsl:with-param name="VereisteWaarde" select="'2|4'"/>
			<xsl:with-param name="ConditioneelElement" select="$Berichtcode"/>
			<xsl:with-param name="ConditioneleWaarde" select="'584'"/>
			<xsl:with-param name="Retourcode" select="'9263'"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC006:De waarde van Verzenddatum moet kleiner zijn dan of gelijk zijn aan de waarde van de huidige datum. -->
	<xsl:variable name="vc006">
		<xsl:call-template name="rcDatum_vs_SpecifiekeDatum">
			<xsl:with-param name="TeControlerenDatum" select="$Verzenddatum"/>
			<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
			<xsl:with-param name="SpecifiekeDatum" select="$HuidigeDatum"/>
			<xsl:with-param name="Retourcode" select="'8986'" />
		</xsl:call-template>
	</xsl:variable>
	
<!-- Controleer op fouten in de klasse VerantwoordingsContext -->

<!-- VC007: Indien Berichtcode = 584 (= Verantwoording forensische zorg voor ZPM), dan mag alleen ZorgaanbiederSoort = 1 (= Instelling) voorkomen -->
	<xsl:variable name="vc007">
	<xsl:call-template name="rcCheckWaarde_ConditioneleWaarde">
		<xsl:with-param name="TeControlerenElement" select="$ZorgaanbiederSoort"/>
		<xsl:with-param name="VereisteWaarde" select="'1'"/>
		<xsl:with-param name="ConditioneelElement" select="$Berichtcode"/>
		<xsl:with-param name="ConditioneleWaarde" select="'584'"/>
		<xsl:with-param name="Retourcode" select="'9620'"/>
	</xsl:call-template>
</xsl:variable>
	<!-- VC008:De waarde van EinddatumVerantwoordingsperiode moet kleiner zijn dan of gelijk zijn aan de waarde van verzenddatum. -->
	<xsl:variable name="vc008">
		<xsl:call-template name="rcDatum_vs_Peildatum">
			<xsl:with-param name="TeControlerenDatum" select="$EinddatumVerantwoordingsperiode"/>
			<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
			<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
			<xsl:with-param name="Retourcode" select="'9636'" />
		</xsl:call-template>
	</xsl:variable>

<!-- Controleer op fouten in de klasse Overzicht -->
<!-- VC009: De waarde van TotaalAngZpm, rekening houdend met debet/credit, moet gelijk zijn aan de som van de waarden van DeclaratiebedragInclBtw, rekening houdend met alle DebetPrestaties en alle CreditPrestaties. -->
	<xsl:variable name="vc009">
	<xsl:call-template name="rcTotaalbedragDC_vs_Details">
			<xsl:with-param name="NaamBedrag" select="'TotaalAngZpm'"/>
			<xsl:with-param name="TotaalBedrag" select="//fz813:Bericht/fz813:Overzicht/fz813:TotaalAngZpm/fz813:Bedrag"/>
			<xsl:with-param name="TotaalBedragDCIndicator" select="//fz813:Bericht/fz813:Overzicht/fz813:TotaalAngZpm/fz813:DebetCreditCode"/>
			<xsl:with-param name="TotaalDebetBedragen" select="sum(//fz813:Bericht/fz813:Verzekerde/fz813:Prestatie/fz813:DebetPrestatie/fz813:DeclaratieBedragInclBtw)"/>
			<xsl:with-param name="TotaalCreditBedragen" select="sum(//fz813:Bericht/fz813:Verzekerde/fz813:Prestatie/fz813:CreditPrestatie/fz813:DeclaratieBedragInclBtw)"/>
		<xsl:with-param name="Retourcode" select="'9622'"/>
	</xsl:call-template>
</xsl:variable>

	<!-- Opbouwen retourbericht -->
	<xsl:template match="fz813:Bericht">
		<fz814:Bericht>
			<xsl:apply-templates select="fz813:Header"/>					
			<xsl:apply-templates select="fz813:VerantwoordingsContext"/>	
			<xsl:apply-templates select="fz813:Overzicht"/>
			<xsl:if test="$rc003='' and $rc006='' and $vc001='' and $vc002='' and $vc004='' and $vc006='' and $vc007='' and $vc008='' and $vc009=''">
				<xsl:apply-templates select="fz813:Verzekerde"/>
			</xsl:if>
		</fz814:Bericht>
	</xsl:template>

	<xsl:template match="fz813:Header">  
		<fz814:Header>
			<fz814:Berichtcode>585</fz814:Berichtcode>
			<xsl:apply-templates select="fz813:Berichtversie" mode="copy-if-exists"/>	
			<xsl:apply-templates select="fz813:Berichtsubversie" mode="copy-if-exists"/>  
			<xsl:apply-templates select="fz813:Berichtsoort" mode="copy-if-exists"/>
			<!-- als Vecozo is verzender van het retourbericht dan vullen met gegevens van Vecozo, anders met de gegevens van de verzender van het declaratiebericht -->
			<xsl:choose>
				<xsl:when test="$VerzenderRetourbericht = 'Vecozo'">
					<fz814:VerzenderRol>
						<xsl:value-of select="$VerzenderRolVecozo"/>
					</fz814:VerzenderRol>
				</xsl:when>
				<xsl:otherwise>
					<fz814:Verzender><xsl:value-of select="fz813:Ontvanger"/></fz814:Verzender>
					<fz814:VerzenderRol><xsl:value-of select="fz813:OntvangerRol"/></fz814:VerzenderRol>
				</xsl:otherwise>
			</xsl:choose>
			<!-- Ontvanger in retourbericht is Verzender uit declaratiebericht -->
			<fz814:Ontvanger><xsl:value-of select="fz813:Verzender"/></fz814:Ontvanger>
			<!-- OntvangerRol in retourbericht is VerzenderRol uit declaratiebericht -->
			<fz814:OntvangerRol><xsl:value-of select="fz813:VerzenderRol"/></fz814:OntvangerRol>
			<fz814:Verzenddatum><xsl:value-of select="$HuidigeDatum"/></fz814:Verzenddatum>
			<xsl:apply-templates select="fz813:Referentienummer" mode="copy-if-exists"/>
			<!-- feedback klasse Header toevoegen -->
			<xsl:copy-of select="$rc003"/>
			<xsl:copy-of select="$rc006"/>
			<xsl:copy-of select="$vc001"/>		
			<xsl:copy-of select="$vc002"/>
			<xsl:copy-of select="$vc004"/>
			<xsl:copy-of select="$vc006"/>
		</fz814:Header>
	</xsl:template>
	
	<xsl:template match="fz813:VerantwoordingsContext">
		<fz814:VerantwoordingsContext>
			<xsl:apply-templates select="fz813:Declarant"/>
			<xsl:apply-templates select="fz813:EinddatumVerantwoordingsperiode" mode="copy-if-exists"/>		
			<!-- feedback klasse VerantwoordingsContext toevoegen -->
			<xsl:copy-of select="$vc007"/>
			<xsl:copy-of select="$vc008"/>
		</fz814:VerantwoordingsContext>
	</xsl:template>	

	<xsl:template match="fz813:Declarant">  
		<fz814:Declarant>
			<xsl:apply-templates select="fz813:Zorgaanbiedercode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz813:ZorgaanbiederSoort" mode="copy-if-exists"/>
		</fz814:Declarant>
	</xsl:template>	

	<xsl:template match="fz813:Overzicht">
		<fz814:Overzicht>
			<xsl:apply-templates select="fz813:TotaalAngZpm"/>
			<!-- feedback klasse Overzicht toevoegen -->
			<xsl:copy-of select="$vc009"/>
		</fz814:Overzicht>
	</xsl:template>	
	
	<xsl:template match="fz813:TotaalAngZpm">  
		<xsl:variable name="DebetCreditCode" select="fz813:DebetCreditCode"/> 		
		<!-- RC010: DebetCreditCode moet voorkomen in Indicatie debet/credit codelijst. -->
		<xsl:variable name="rc010">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/COD043-VEKT.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9406'"/>
				<xsl:with-param name="RetourcodeIngangsdatum" select="'nvt'"/>
				<xsl:with-param name="RetourcodeExpiratiedatum" select="'nvt'"/>
				<xsl:with-param name="Code" select="$DebetCreditCode"/>
				<xsl:with-param name="Peildatum" select="'nvt'"/>
			</xsl:call-template>
		</xsl:variable>
		<fz814:TotaalAngZpm>
			<xsl:apply-templates select="fz813:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz813:DebetCreditCode" mode="copy-if-exists"/>
			<xsl:copy-of select="$rc010"/>
		</fz814:TotaalAngZpm>
	</xsl:template>	
	
	<xsl:template match="fz813:Verzekerde">
		<fz814:Verzekerde>
			<xsl:apply-templates select="fz813:Verzekerdennummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz813:Prestatie"/>
		</fz814:Verzekerde>
	</xsl:template>	
	
	<xsl:template match="fz813:Prestatie">
		<fz814:Prestatie>
			<xsl:apply-templates select="fz813:DebetPrestatie"/>
			<xsl:apply-templates select="fz813:CreditPrestatie"/>
		</fz814:Prestatie>
	</xsl:template>	

	<xsl:template match="fz813:DebetPrestatie">
		<xsl:variable name="PrestatieCodelijstCode" select="fz813:PrestatieCodelijstCode"/>
		<xsl:variable name="Begindatum" select="fz813:Begindatum"/>
		<xsl:variable name="Aantal" select="fz813:Aantal"/>
		<!-- Controleer op fouten in de klasse Prestatie -->
		<!-- RC008: PrestatieCodelijstCode moet voorkomen in aanduiding prestatiecodelijst codelijst. -->
		<xsl:variable name="rc008">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/COD367-VEKT.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9334'"/>
				<xsl:with-param name="RetourcodeIngangsdatum" select="'nvt'"/>
				<xsl:with-param name="RetourcodeExpiratiedatum" select="'nvt'"/>
				<xsl:with-param name="Code" select="$PrestatieCodelijstCode"/>
				<xsl:with-param name="Peildatum" select="'nvt'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC010: Indien Berichtcode = 584 (= Verantwoording forensische zorg voor ZPM), dan moet PrestatieCodelijstCode = 071 (= Prestatiecodelijst geestelijke gezondheidszorg en forensische zorg volgens ZPM) voorkomen. -->
		<xsl:variable name="vc010">
			<xsl:call-template name="rcCheckWaarde_ConditioneleWaarde">
				<xsl:with-param name="TeControlerenElement" select="$PrestatieCodelijstCode"/>
				<xsl:with-param name="VereisteWaarde" select="'071'"/>
				<xsl:with-param name="ConditioneelElement" select="$Berichtcode"/>
				<xsl:with-param name="ConditioneleWaarde" select="'584'"/>
				<xsl:with-param name="Retourcode" select="'9623'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC011: De waarde van DebetPrestatie/Begindatum moet kleiner zijn dan of gelijk zijn aan de waarde van EinddatumVerantwoordingsperiode. -->
		<xsl:variable name="vc011">
			<xsl:call-template name="rcDatum_vs_Peildatum">
				<xsl:with-param name="TeControlerenDatum" select="$Begindatum"/>
				<xsl:with-param name="Peildatum" select="$EinddatumVerantwoordingsperiode"/>
				<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9624'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC012:DebetPrestatie/Begindatum mag niet voor 1 januari van het jaar van de EinddatumVerantwoordingsperiode liggen.-->
		<xsl:variable name="vc012">
			<xsl:call-template name="rcDatum_vs_SpecifiekeDatum">
				<xsl:with-param name="TeControlerenDatum" select="fz813:Begindatum"/>
				<xsl:with-param name="Vergelijking" select="'groterofgelijkaan'"/>
				<xsl:with-param name="SpecifiekeDatum" select="concat(substring($EinddatumVerantwoordingsperiode,1,4),'-01-01')"/>
				<xsl:with-param name="Retourcode" select="'9638'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC013:De waarde van DebetPrestatie/ Begindatum moet kleiner zijn dan of gelijk zijn aan de waarde van Verzenddatum. -->
		<xsl:variable name="vc013">
			<xsl:call-template name="rcDatum_vs_Peildatum">
				<xsl:with-param name="TeControlerenDatum" select="$Begindatum"/>
				<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
				<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'8989'" />
			</xsl:call-template>
		</xsl:variable>
		<!-- VC014: Aantal moet gelijk zijn aan ‘1’. -->
		<xsl:variable name="vc014">
			<xsl:call-template name="rcCheckWaarde">
				<xsl:with-param name="TeControlerenElement" select="$Aantal"/>
				<xsl:with-param name="VereisteWaarde" select="'1'"/>
				<xsl:with-param name="Retourcode" select="'8049'"/>
			</xsl:call-template>
		</xsl:variable>
		<fz814:DebetPrestatie>
			<xsl:apply-templates select="fz813:Referentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz813:AanvullendePrestatiegegevens"/>
			<!-- feedback klasse DebetPrestatie toevoegen -->
			<xsl:copy-of select="$rc008"/>			
			<xsl:copy-of select="$vc010"/>
			<xsl:copy-of select="$vc011"/>
			<xsl:copy-of select="$vc012"/>
			<xsl:copy-of select="$vc013"/>
			<xsl:copy-of select="$vc014"/>
		</fz814:DebetPrestatie>
	</xsl:template>	
	
	<xsl:template match="fz813:AanvullendePrestatiegegevens">
		<fz814:AanvullendePrestatiegegevens>
			<xsl:apply-templates select="fz813:Plaatsingsbesluit"/>
		</fz814:AanvullendePrestatiegegevens>
	</xsl:template>	

	<xsl:template match="fz813:Plaatsingsbesluit">
		<fz814:Plaatsingsbesluit>
		</fz814:Plaatsingsbesluit>
	</xsl:template>
	
	<xsl:template match="fz813:CreditPrestatie">
		<xsl:variable name="PrestatieCodelijstCode" select="fz813:PrestatieCodelijstCode"/>
		<xsl:variable name="Begindatum" select="fz813:Begindatum"/>
		<!-- Controleer op fouten in de klasse Prestatie -->
		<!-- RC008: PrestatieCodelijstCode moet voorkomen in aanduiding prestatiecodelijst codelijst. -->
		<xsl:variable name="rc008">
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/COD367-VEKT.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9335'"/>
				<xsl:with-param name="RetourcodeIngangsdatum" select="'nvt'"/>
				<xsl:with-param name="RetourcodeExpiratiedatum" select="'nvt'"/>
				<xsl:with-param name="Code" select="$PrestatieCodelijstCode"/>
				<xsl:with-param name="Peildatum" select="'nvt'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC015:De waarde van CreditPrestatie/GerelateerdReferentienummer mag niet gelijk zijn aan de waarde van DebetPrestatie/Referentienummer in bericht. --> 
		<xsl:variable name="vc015">
			<xsl:call-template name="rcCheckWaarde_vs_Key">
				<xsl:with-param name="TeControlerenElement" select="fz813:GerelateerdReferentienummer"/>
				<xsl:with-param name="Controle" select="'N'"/>
				<xsl:with-param name="KeyElement" select="'DebetReferentienummer'"/>
				<xsl:with-param name="Retourcode" select="'8062'"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- VC016: De waarde van CreditPrestatie/Begindatum moet kleiner zijn dan of gelijk zijn aan de waarde van EinddatumVerantwoordingsperiode. -->
		<xsl:variable name="vc016">
			<xsl:call-template name="rcDatum_vs_Peildatum">
				<xsl:with-param name="TeControlerenDatum" select="$Begindatum"/>
				<xsl:with-param name="Peildatum" select="$EinddatumVerantwoordingsperiode"/>
				<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
				<xsl:with-param name="Retourcode" select="'9624'"/>
			</xsl:call-template>
		</xsl:variable>
		<fz814:CreditPrestatie>
			<xsl:apply-templates select="fz813:Referentienummer" mode="copy-if-exists"/>
			<!-- feedback klasse CreditPrestatie toevoegen -->
			<xsl:copy-of select="$rc008"/>			
			<xsl:copy-of select="$vc015"/>
			<xsl:copy-of select="$vc016"/>
		</fz814:CreditPrestatie>
	</xsl:template>	
	
	<!-- Copy template: als een enkel element voorkomt, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="*[namespace-uri()='http://ei.vektis.nl/verantwoording/fz813']" mode="copy-if-exists">
		<xsl:if test=".">
			<xsl:element name="{concat($TargetNameSpace,local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>