<?xml version="1.0" encoding="UTF-8"?>
<!-- vz845_586v1.0_Vecozo_stap2_v1, 4 april 2024 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:gen="http://ei.vektis.nl/generiekefuncties"		
xmlns:fz814="http://ei.vektis.nl/verantwoording/fz814">

	<!-- VALXSLT 2 TRAPS RETOURBERICHT  - versie Vecozo -->
	<!-- Deze xslt doet stap 2, i.e. filteren overbodige ballast met eindresultaat retourbericht -->
	<!-- LET OP: feedback uit stap 1 moet in resultaat van stap 1 (input voor stap 2) worden aangeboden met namespace 'gen' -->
	
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
		
	<xsl:variable name="TargetNameSpace" select="'fz814:'"/>

	<xsl:template match="//fz814:Bericht">
		<fz814:Bericht>
			<!-- neem in retourbericht op volgens welke XSD het retourbericht is opgebouwd -->
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/verantwoording/fz814 fz814_585.xsd</xsl:attribute>
			<xsl:apply-templates select="fz814:Header"/>
			<xsl:apply-templates select="fz814:VerantwoordingsContext"/>
			<xsl:apply-templates select="fz814:Overzicht"/>
			<xsl:apply-templates select="fz814:Verzekerde"/>
		</fz814:Bericht>
	</xsl:template>
	
	<xsl:template match="fz814:Header">
		<fz814:Header>
			<!-- kopieer alle elementen die in stap 1 zijn geselecteerd -->
			<xsl:apply-templates select="fz814:Berichtcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz814:Berichtversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz814:Berichtsubversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz814:Berichtsoort" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz814:Verzender" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz814:VerzenderRol" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz814:Ontvanger" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz814:OntvangerRol" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz814:Verzenddatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz814:Referentienummer" mode="copy-if-exists"/>
			<!-- retourneer eventuele feedback -->
			<xsl:apply-templates select="gen:Feedback"/>
		</fz814:Header>
	</xsl:template>

	<xsl:template match="fz814:VerantwoordingsContext">
		<fz814:VerantwoordingsContext>
			<xsl:apply-templates select="fz814:Declarant"/>
			<!-- kopieer alle elementen die in stap 1 zijn geselecteerd -->
			<xsl:apply-templates select="fz814:EinddatumVerantwoordingsperiode" mode="copy-if-exists"/>
			<!-- retourneer eventuele feedback -->
			<xsl:apply-templates select="gen:Feedback"/>
		</fz814:VerantwoordingsContext>
	</xsl:template>

	<xsl:template match="fz814:Declarant">
		<fz814:Declarant>
			<!-- kopieer alle elementen die in stap 1 zijn geselecteerd -->
			<xsl:apply-templates select="fz814:Zorgaanbiedercode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz814:ZorgaanbiederSoort" mode="copy-if-exists"/>
			<!-- retourneer eventuele feedback -->
			<xsl:apply-templates select="gen:Feedback"/>
		</fz814:Declarant>
	</xsl:template>

	<xsl:template match="fz814:Overzicht">
		<fz814:Overzicht>
			<xsl:apply-templates select="fz814:TotaalAngZpm"/>
			<!-- retourneer eventuele feedback -->
			<xsl:apply-templates select="gen:Feedback"/>
		</fz814:Overzicht>
	</xsl:template>

	<xsl:template match="fz814:TotaalAngZpm">
		<fz814:TotaalAngZpm>
			<!-- kopieer alle elementen die in stap 1 zijn geselecteerd -->
			<xsl:apply-templates select="fz814:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz814:DebetCreditCode" mode="copy-if-exists"/>
			<!-- retourneer eventuele feedback -->
			<xsl:apply-templates select="gen:Feedback"/>
		</fz814:TotaalAngZpm>
	</xsl:template>

	<xsl:template match="fz814:Verzekerde">
		<!-- onderstaande test gaat na of in de huidige klasse en/of subklassen de string 'gen:Feedback' voorkomt -->
		<!-- zo ja, dan is sprake van een fout en moet de klasse worden geretourneerd in retourbericht -->
		<xsl:if test=".//gen:Feedback">
			<fz814:Verzekerde>
				<!-- kopieer alle elementen die in stap 1 zijn geselecteerd -->
				<xsl:apply-templates select="fz814:Verzekerdennummer" mode="copy-if-exists"/>
				<xsl:apply-templates select="fz814:Prestatie"/>
				<!-- retourneer eventuele feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</fz814:Verzekerde>
		</xsl:if>
	</xsl:template>

	<xsl:template match="fz814:Prestatie">
		<!-- onderstaande test gaat na of in de huidige klasse en/of subklassen de string 'gen:Feedback' voorkomt -->
		<!-- zo ja, dan is sprake van een fout en moet de klasse worden geretourneerd in retourbericht -->
		<xsl:if test=".//gen:Feedback">
			<fz814:Prestatie>
				<xsl:apply-templates select="fz814:DebetPrestatie"/>
				<xsl:apply-templates select="fz814:CreditPrestatie"/>
			</fz814:Prestatie>
		</xsl:if>
	</xsl:template>

	<xsl:template match="fz814:DebetPrestatie">
		<!-- onderstaande test gaat na of in de huidige klasse en/of subklassen de string 'gen:Feedback' voorkomt -->
		<!-- zo ja, dan is sprake van een fout en moet de klasse worden geretourneerd in retourbericht -->
		<xsl:if test=".//gen:Feedback">
			<fz814:DebetPrestatie>
				<!-- kopieer alle elementen die in stap 1 zijn geselecteerd -->
				<xsl:apply-templates select="fz814:Referentienummer" mode="copy-if-exists"/>
				<xsl:apply-templates select="fz814:AanvullendePrestatiegevens"/>
				<!-- retourneer eventuele feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</fz814:DebetPrestatie>
		</xsl:if>
	</xsl:template>

	<xsl:template match="fz814:AanvullendePrestatiegevens">
		<!-- onderstaande test gaat na of in de huidige klasse en/of subklassen de string 'gen:Feedback' voorkomt -->
		<!-- zo ja, dan is sprake van een fout en moet de klasse worden geretourneerd in retourbericht -->
		<xsl:if test=".//gen:Feedback">
			<fz814:AanvullendePrestatiegevens>
				<xsl:apply-templates select="fz814:Plaatsingsbesluit"/>
				<!-- retourneer eventuele feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</fz814:AanvullendePrestatiegevens>
		</xsl:if>
	</xsl:template>

	<xsl:template match="fz814:Plaatsingsbesluit">
		<!-- onderstaande test gaat na of in de huidige klasse en/of subklassen de string 'gen:Feedback' voorkomt -->
		<!-- zo ja, dan is sprake van een fout en moet de klasse worden geretourneerd in retourbericht -->
		<xsl:if test=".//gen:Feedback">
			<fz814:Plaatsingsbesluit>
				<!-- retourneer eventuele feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</fz814:Plaatsingsbesluit>
		</xsl:if>
	</xsl:template>

	<xsl:template match="fz814:CreditPrestatie">
		<!-- onderstaande test gaat na of in de huidige klasse en/of subklassen de string 'gen:Feedback' voorkomt -->
		<!-- zo ja, dan is sprake van een fout en moet de klasse worden geretourneerd in retourbericht -->
		<xsl:if test=".//gen:Feedback">
			<fz814:CreditPrestatie>
				<!-- kopieer alle elementen die in stap 1 zijn geselecteerd -->
				<xsl:apply-templates select="fz814:Referentienummer" mode="copy-if-exists"/>
				<!-- retourneer eventuele feedback -->
				<xsl:apply-templates select="gen:Feedback"/>
			</fz814:CreditPrestatie>
		</xsl:if>
	</xsl:template>

	<xsl:template match="gen:Feedback">
	<fz814:Feedback>
		<xsl:apply-templates select="gen:Retourcode" mode="copy-if-exists"/>
		<xsl:apply-templates select="gen:BetrokkenElement"/>
	</fz814:Feedback>
	</xsl:template>
	
	<xsl:template match="gen:BetrokkenElement">
		<fz814:BetrokkenElement>
			<xsl:apply-templates select="*" mode="copy-if-exists"/>
		</fz814:BetrokkenElement>
	</xsl:template>
	
	<!-- Copy template: als een enkel element voorkomt is, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="*[namespace-uri()='http://ei.vektis.nl/verantwoording/fz814']" mode="copy-if-exists">
		<xsl:if test=".">
			<xsl:element name="{concat($TargetNameSpace,local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="*[namespace-uri()='http://ei.vektis.nl/generiekefuncties']" mode="copy-if-exists">
		<xsl:if test=".">
			<xsl:element name="{concat($TargetNameSpace,local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
